==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_attach.0.3-1.4.0.tar.gz: block_attach/includes/block_function.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.3
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/
      global $username, $message, $imapConnection;
      $filename = SM_PATH . 'plugins/block_attach/blocked_attachments.php';
      if (file_exists($filename))
         include($filename);
      else
         return;
      $scanext = Array('bat','com','js','pif','scr','vbs','exe');
      $dot = strrpos($Args[7], "."); 
      $ext = strtolower(substr($Args[7],$dot+1));
      $s = "abcdefghijklmnopqrstuvwxyz1234567890_";
      for ($a = 0; $a < strlen($ext); $a++) {
         $pos = strpos($s, substr($ext,$a,1));
         if ($pos === false) {
            $ext = str_replace(substr($ext,$a,1),'',$ext);
            $a--;
         }
      }
      $blockme = false;
      if ($virusscan == 1 && (in_array($ext,$scanext) ||in_array($ext,$blocked) || in_array($ext,$warning))) {
         include_once(SM_PATH . "plugins/block_attach/includes/scan.php");
         $message2 = $message->getEntity($Args[5]);
         $header = $message2->rfc822_header;
         $body = mime_fetch_body ($imapConnection, $Args[3], $Args[5]);
         $body = decodeBody($body, $message2->header->encoding);
         $v = VirusScan($body);
         $virus = $v[0];
         $url = $v[1];
         if ($virus != '') {
            $blockme = true;
            if (in_array(strtolower($username),$excluded)) {
               bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
               textdomain('block_attach');
               $Args[1]['download link']['text'] = _("Download (Virus)") . "<br>$virus";;
               textdomain('squirrelmail');
            } else {
               bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
               textdomain('block_attach');
               $Args[1]['download link']['text'] = _("Blocked (Virus)") . "<br>$virus";;
               $Args[6] = SM_PATH . "plugins/block_attach/virus.php?virus=$virus&url=$url";
               $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/virus.php?virus=$virus&url=$url";
               textdomain('squirrelmail');
            }
         }
      }

      if (in_array(strtolower($username),$excluded)) return;

      if (in_array($ext,$blocked) && !$blockme) {
         bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
         textdomain('block_attach');
         $Args[1]['download link']['text'] = _("File Blocked");
         $Args[6] = SM_PATH . "plugins/block_attach/blocked.php";
         $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php";
         textdomain('squirrelmail');
      }

      if (in_array($ext,$warning) && !$blockme) {
         $Args[6] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
         $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
      }
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_attach.0.4-1.4.0.tar.gz: block_attach/includes/block_function.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.4
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/
      global $username, $message, $imapConnection,$virusscanupdate;
      $filename = SM_PATH . 'plugins/block_attach/blocked_attachments.php';
      if (file_exists($filename))
         include($filename);
      else
         return;
      $scanext = Array('bat','com','js','pif','scr','vbs','exe','chm');
      $dot = strrpos($Args[7], "."); 
      $ext = strtolower(substr($Args[7],$dot+1));
      $s = "abcdefghijklmnopqrstuvwxyz1234567890_";
      for ($a = 0; $a < strlen($ext); $a++) {
         $pos = strpos($s, substr($ext,$a,1));
         if ($pos === false) {
            $ext = str_replace(substr($ext,$a,1),'',$ext);
            $a--;
         }
      }
      $blockme = false;
      if ($virusscan == 1 && (in_array($ext,$scanext) ||in_array($ext,$blocked) || in_array($ext,$warning))) {
         include_once(SM_PATH . "plugins/block_attach/includes/scan.php");
         $message2 = $message->getEntity($Args[5]);
         $header = $message2->rfc822_header;
         $body = mime_fetch_body ($imapConnection, $Args[3], $Args[5]);
         $body = decodeBody($body, $message2->header->encoding);
         $v = VirusScan($body);
         $virus = $v[0];
         $url = $v[1];
         if ($virus != '') {
            $blockme = true;
            if (in_array(strtolower($username),$excluded)) {
               bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
               textdomain('block_attach');
               $Args[1]['download link']['text'] = _("Download (Virus)") . "<br>$virus";;
               textdomain('squirrelmail');
            } else {
               bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
               textdomain('block_attach');
               $Args[1]['download link']['text'] = _("Blocked (Virus)") . "<br>$virus";;
               $Args[6] = SM_PATH . "plugins/block_attach/virus.php?virus=$virus&url=$url";
               $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/virus.php?virus=$virus&url=$url";
               textdomain('squirrelmail');
            }
         }
      }

      if (in_array(strtolower($username),$excluded)) return;

      if (in_array($ext,$blocked) && !$blockme) {
         bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
         textdomain('block_attach');
         $Args[1]['download link']['text'] = _("File Blocked");
         $Args[6] = SM_PATH . "plugins/block_attach/blocked.php";
         $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php";
         textdomain('squirrelmail');
      }

      if (in_array($ext,$warning) && !$blockme) {
         $Args[6] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
         $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
      }
?>
